版本 - 互联网公墓

# 版本

跳到导航 跳到搜索

## MediaWiki协议

本wiki由MediaWiki驱动，版权所有 © 2001-2024 Magnus Manske、Brion Vibber、Lee Daniel Crocker、Tim Starling、Erik Möller、Gabriel Wicke、Ævar Arnfjörð Bjarmason、Niklas Laxström、Domas Mituzas、Rob Church、Yuri Astrakhan、Aryeh Gregor、Aaron Schulz、Andrew Garrett、Raimond Spekking、Alexandre Emsenhuber、Siebrand Mazeland、Chad Horohoe、Roan Kattouw、Trevor Parscal、Bryan Tong Minh、Sam Reed、Victor Vasiliev、Rotem Liss、Platonides、Antoine Musso、Timo Tijhof、Daniel Kinzler、Jeroen De Dauw、Brad Jorsch、Bartosz Dziewoński、Ed Sanders、Moriel Schottlender、Kunal Mehta、James D. Forrester、Brian Wolff、Adam Shorland、DannyS712、其他和translatewiki.net上的翻译者。

MediaWiki是自由软件；您可以依据自由软件基金会发行的GNU通用公共许可协议第2版或任意后续版本的条款，传播和/或修改本软件。

MediaWiki发表时预期有用，但对此无任何保证；亦无隐含的可以销售或适合特定目的的保证。详情请见GNU公众授权协议。

您应该已经接受本程序附带的GNU通用公共许可协议的副本；如果没有，请写信至美国马萨诸塞州波士顿富兰克林大街51号5楼自由软件基金会，邮编MA 02110-1301（Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA），或在线阅读该协议。

## 安装的软件

产品 | 版本
--- | ---
MediaWiki | 1.36.1
PHP | 7.4.30 (fpm-fcgi)
MySQL | 5.7.34-log
ICU | 50.2
Lua | 5.1.5

## 接入点URL

接入点 | URL
--- | ---
条目路径 | `/wiki/$1`
脚本路径 | `/`
index.php | `/index.php`
api.php | `/api.php`
rest.php | `/rest.php`

## 安装的皮肤

皮肤 | 版本 | 许可协议 | 描述 | 作者
--- | --- | --- | --- | ---
MonoBook | – | GPL-2.0-or-later | 自2004年就出现的经典MediaWiki皮肤，命名依据一本书中某页面的黑白照片背景 | Gabriel Wicke、Isarra Yos和其他
Timeless | 0.9.1 | GPL-2.0-or-later | 在由Brandon Harris设计的冬季标准之后设计的一个不受时间影响的皮肤，以及一些来自维基媒体基金会的风格 | Isarra Yos
Vector | 1.0.0 | GPL-2.0-or-later | 有着清新外观和许多可用性改进的现代版MonoBook皮肤 | Trevor Parscal、Roan Kattouw和其他

## 安装的扩展程序

特殊页面
扩展程序 | 版本 | 许可协议 | 描述 | 作者
--- | --- | --- | --- | ---
CiteThisPage | – | GPL-2.0-or-later | 添加引用特殊页面和工具箱链接 | Ævar Arnfjörð Bjarmason和James D. Forrester
Interwiki | 3.2 | GPL-2.0-or-later | 新增特殊页面以查看和编辑跨wiki表 | Stephanie Amanda Stevens、Alexandre Emsenhuber、Robin Pepermans、Siebrand Mazeland、Platonides、Raimond Spekking、Sam Reed、Jack Phoenix、Calimonius the Estrange和其他
Nuke | – | GPL-2.0-or-later | 让管理员可以大量删除页面 | Brion Vibber和Jeroen De Dauw
Renameuser | – | GPL-2.0-or-later | 添加更改用户名的特殊页面（需要renameuser权限） | Ævar Arnfjörð Bjarmason和Aaron Schulz
Replace Text | 1.4.1 | GPL-2.0-or-later | 提供特殊页面让管理员可以对wiki的所有页面内容执行查找和替换。 | Yaron Koren、Niklas Laxström和其他
编辑器
扩展程序 | 版本 | 许可协议 | 描述 | 作者
CodeEditor | – | GPL-2.0-or-later AND BSD-3-Clause | 使用Ace编辑器实现编辑JavaScript和CSS页面时的语法高亮功能 | Brion Vibber、Derk-Jan Hartman和authors of Ace
VisualEditor | 0.1.2 | MIT | MediaWiki的可视化编辑器 | Alex Monk、Bartosz Dziewoński、C. Scott Ananian、Christian Williams、David Lynch、Ed Sanders、Inez Korczyński、James D. Forrester、Moriel Schottlender、Roan Kattouw、Rob Moen、Subramanya Sastry、Thalia Chan、Timo Tijhof、Trevor Parscal和其他
WikiEditor | 0.5.3 | GPL-2.0-or-later | 提供高级、可扩展的wiki语法编辑界面 | Derk-Jan Hartman、Trevor Parscal、Roan Kattouw、Nimish Gautam和Adam Miller
解析器钩
扩展程序 | 版本 | 许可协议 | 描述 | 作者
CategoryTree | – | GPL-2.0-or-later | 动态导航分类结构 | Daniel Kinzler
Cite | – | GPL-2.0-or-later | 增加用于引用的`<ref>`和`<references/>`标签 | Ævar Arnfjörð Bjarmason、Andrew Garrett、Brion Vibber、Ed Sanders、Marius Hoch、Steve Sanbeg、Trevor Parscal和其他
ImageMap | – | GPL-2.0-or-later | 容许客户端可以使用`<imagemap>`标签整可点击图像地图 | Tim Starling
InputBox | 0.3.0 | MIT | 允许包含预先设置的HTML表单 | Erik Moeller、Leonardo Pimenta、Rob Church、Trevor Parscal和DaSch
ParserFunctions | 1.6.0 | GPL-2.0-or-later | 用逻辑函数加强解析器 | Tim Starling、Robert Rohde、Ross McClure和Juraj Simlovic
Poem | – | CC0-1.0 | 添加`<poem>`标签用于诗歌格式 | Nikola Smolenski、Brion Vibber和Steve Sanbeg
Scribunto | – | GPL-2.0-or-later AND MIT | 用于在MediaWiki页面中嵌入脚本语言的框架 | Victor Vasiliev、Tim Starling和Brad Jorsch
SyntaxHighlight | 2.0 | GPL-2.0-or-later | 使用Pygments - Python 语法高亮以提供语法高亮`<syntaxhighlight>` | Brion Vibber、Tim Starling、Rob Church、Niklas Laxström、Ori Livneh和Ed Sanders
TemplateData | 0.1.2 | GPL-2.0-or-later | 实现模板参数的数据存储（使用JSON） | Timo Tijhof、Moriel Schottlender、James D. Forrester、Trevor Parscal、Bartosz Dziewoński、Marielle Volz和其他
模板样式 | 1.0 (e548bf1) 2021年5月28日 (五) 12:55 | GPL-2.0-or-later | 实施基于模板的样式表 | Brad Jorsch和Marc A. Pelletier
媒体文件处理器
扩展程序 | 版本 | 许可协议 | 描述 | 作者
PDF Handler | – | GPL-2.0-or-later | 在图像模式中查看PDF文件的处理器。 | Martin Seidel和Mike Połtyn
垃圾阻止
扩展程序 | 版本 | 许可协议 | 描述 | 作者
ConfirmEdit | 1.6.0 | GPL-2.0-or-later | 提供验证码技术防止垃圾信息和密码破解破坏 | Brion Vibber、Florian Schmidt、Sam Reed和其他
TitleBlacklist | 1.5.0 | GPL-2.0-or-later | 允许管理员通过黑名单和白名单禁止页面和用户帐户的创建 | Victor Vasiliev和Fran Rogers
API
扩展程序 | 版本 | 许可协议 | 描述 | 作者
PageImages | – | WTFPL | 收集有关图像在页面上使用的信息 | Max Semenik
其他
扩展程序 | 版本 | 许可协议 | 描述 | 作者
Gadgets | – | GPL-2.0-or-later | 允许用户在其系统设置中选择自定义CSS和JavaScript工具 | Daniel Kinzler和Max Semenik
LocalisationUpdate | 1.4.0 | GPL-2.0-or-later | 将本地化的信息保持最新 | Tom Maaswinkel、Niklas Laxström和Roan Kattouw
MultimediaViewer | – | GPL-2.0-or-later | 在全屏界面中以较大尺寸显示缩略图。 | MarkTraceur (Mark Holmquist)、Gilles Dubuc、Gergő Tisza、Aaron Arcos、Zeljko Filipin、Pau Giner、theopolisme、MatmaRex、apsdehal、vldandrew、Ebrahim Byagowi、Dereckson、Brion VIBBER、Yuki Shira、Yaroslav Melnychuk、tonythomas01、Raimond Spekking、Kunal Mehta、Jeff Hall、Christian Aistleitner、Amir E. Aharoni和其他
OATHAuth | 0.5.0 | GPL-2.0-or-later AND GPL-3.0-or-later | 提供“基于HMAC的一次性密码”的身份验证支持 | Ryan Lane、Robert Vogel <vogel@hallowelt.com>和Dejan Savuljesku <savuljesku@hallowelt.com>
SecureLinkFixer | – | GPL-3.0-or-later | Rewrites URLs to HTTPS if domain always requires HTTPS | Kunal Mehta
TextExtracts | – | GPL-2.0-or-later | 提供纯文本或有限的HTML页面内容提取 | Max Semenik

## 安装的库

库 | 版本 | 许可协议 | 描述 | 作者
--- | --- | --- | --- | ---
christian-riesen/base32 | 1.4.0 | MIT | Base32 encoder/decoder according to RFC 4648 | Christian Riesen
composer/semver | 3.2.4 | MIT | Semver library that offers utilities, version constraint parsing and validation. | Nils Adermann、Jordi Boggiano和Rob Bast
cssjanus/cssjanus | 1.3.0 | Apache-2.0 | Convert CSS stylesheets between left-to-right and right-to-left. | Trevor Parscal、Roan Kattouw和Timo Tijhof
guzzlehttp/guzzle | 7.2.0 | MIT | Guzzle is a PHP HTTP client library | Michael Dowling和Márk Sági-Kazár
guzzlehttp/promises | 1.4.0 | MIT | Guzzle promises library | Michael Dowling
guzzlehttp/psr7 | 1.7.0 | MIT | PSR-7 message implementation that also provides common utility methods | Michael Dowling和Tobias Schultze
jakobo/hotp-php | 2.0.0 | BSD-3-Clause | HOTP simplifies One Time Password systems for PHP Authentication | Jakob Heuser
justinrainbow/json-schema | 5.2.10 | MIT | A library to validate a json schema. | Bruno Prieto Reis、Justin Rainbow、Igor Wiedler和Robert Schönthal
liuggio/statsd-php-client | 1.0.18 | MIT | Statsd (Object Oriented) client library for PHP | Giulio De Donato
monolog/monolog | 2.2.0 | MIT | Sends your logs to files, sockets, inboxes, databases and various web services | Jordi Boggiano
oojs/oojs-ui | 0.41.3 | MIT | Provides library of common widgets, layouts, and windows. | Bartosz Dziewoński、Ed Sanders、James D. Forrester、Kirsten Menger-Anderson、Kunal Mehta、Prateek Saxena、Roan Kattouw、Rob Moen、Timo Tijhof和Trevor Parscal
pear/console_getopt | 1.4.3 | BSD-2-Clause | More info available on: http://pear.php.net/package/Console_Getopt | Andrei Zmievski、Stig Bakken和Greg Beaver
pear/mail | 1.4.1 | BSD-2-Clause | Class that provides multiple interfaces for sending emails. | Chuck Hagenbuch、Richard Heyes和Aleksander Machniak
pear/mail_mime | 1.10.9 | BSD-3-clause | Mail_Mime provides classes to create MIME messages | Cipriano Groenendal和Aleksander Machniak
pear/net_smtp | 1.9.2 | BSD-2-Clause | An implementation of the SMTP protocol | Jon Parise和Chuck Hagenbuch
pear/net_socket | 1.2.2 | PHP License | More info available on: http://pear.php.net/package/Net_Socket | Chuck Hagenbuch、Aleksander Machniak和Stig Bakken
pear/net_url2 | 2.2.2 | BSD-3-Clause | Class for parsing and handling URL. Provides parsing of URLs into their constituent parts (scheme, host, path etc.), URL generation, and resolving of relative URLs. | David Coallier、Tom Klingenberg和Christian Schmidt
pear/pear-core-minimal | 1.10.10 | BSD-3-Clause | Minimal set of PEAR core files to be used as composer dependency | Christian Weiske
pear/pear_exception | 1.0.1 | BSD-2-Clause | The PEAR Exception base class. | Helgi Thormar和Greg Beaver
pleonasm/bloom-filter | 1.0.2 | BSD-2-Clause | A pure PHP implementation of a Bloom Filter | Matthew Nagi
psr/container | 1.0.0 | MIT | Common Container Interface (PHP FIG PSR-11) | PHP-FIG
psr/http-client | 1.0.1 | MIT | Common interface for HTTP clients | PHP-FIG
psr/http-factory | 1.0.1 | MIT | Common interfaces for PSR-7 HTTP message factories | PHP-FIG
psr/http-message | 1.0.1 | MIT | Common interface for HTTP messages | PHP-FIG
psr/log | 1.1.3 | MIT | Common interface for logging libraries | PHP-FIG
psr/simple-cache | 1.0.1 | MIT | Common interfaces for simple caching | PHP-FIG
ralouphie/getallheaders | 3.0.3 | MIT | A polyfill for getallheaders. | Ralph Khattar
wikimedia/assert | 0.5.0 | MIT | Provides runtime assertions | Daniel Kinzler和Thiemo Kreuz
wikimedia/at-ease | 2.1.0 | GPL-2.0-or-later | Safe replacement to @ for suppressing warnings. | Tim Starling和MediaWiki developers
wikimedia/base-convert | 2.0.1 | GPL-2.0-or-later | Convert an arbitrarily-long string from one numeric base to another, optionally zero-padding to a minimum column width. | Brion Vibber和Tyler Romeo
wikimedia/cdb | 1.4.1 | GPL-2.0+ | Constant Database (CDB) wrapper library for PHP. Provides pure-PHP fallback when dba_* functions are absent. | Daniel Kinzler、Tim Starling、Chad Horohoe和Ori Livneh
wikimedia/cldr-plural-rule-parser | 2.0.0 | GPL-2.0-or-later | Evaluates plural rules specified in the CLDR project notation. | Tim Starling和Niklas Laxström
wikimedia/common-passwords | 0.3.0 | MIT | List of the 100,000 most commonly used passwords | Sam Reed
wikimedia/composer-merge-plugin | 2.0.1 | MIT | Composer plugin to merge multiple composer.json files | Bryan Davis
wikimedia/css-sanitizer | 3.0.2 | Apache-2.0 | Classes to parse and sanitize CSS | Brad Jorsch
wikimedia/html-formatter | 3.0.1 | GPL-2.0-or-later | Performs transformations of HTML by wrapping around libxml2 and working around its countless bugs. | MediaWiki contributors
wikimedia/ip-set | 3.0.0 | GPL-2.0-or-later | Efficiently match IP addresses against a set of CIDR specifications. | Brandon Black
wikimedia/ip-utils | 3.0.2 | GPL-2.0-or-later | Functions and constants to play with IP addresses and ranges | MediaWiki developers
wikimedia/less.php | 3.1.0 | Apache-2.0 | PHP port of the Javascript version of LESS http://lesscss.org (Originally maintained by Josh Schmidt) | Josh Schmidt、Matt Agar和Martin Jantošovič
wikimedia/minify | 2.2.3 | Apache-2.0 | Minification of JavaScript code and CSS stylesheets. | Paul Copperman、Trevor Parscal、Timo Tijhof和Roan Kattouw
wikimedia/object-factory | 3.0.0 | GPL-2.0-or-later | Construct objects from configuration instructions | Bryan Davis
wikimedia/parsoid | 0.13.0 | GPL-2.0-or-later | Parsoid, a bidirectional parser between wikitext and HTML5 | Wikimedia Parsing Team and the broader MediaWiki community
wikimedia/php-session-serializer | 2.0.0 | GPL-2.0-or-later | Provides methods like PHP's session_encode and session_decode that don't mess with $_SESSION | Brad Jorsch
wikimedia/purtle | 1.0.7 | GPL-2.0-or-later | Fast streaming RDF serializer | Daniel Kinzler、Stanislav Malyshev、C. Scott Ananian和Thiemo Kreuz
wikimedia/relpath | 2.1.1 | MIT | Compute a relative filepath between two paths. | Ori Livneh
wikimedia/remex-html | 2.2.2 | MIT | Fast HTML 5 parser | Tim Starling
wikimedia/request-timeout | 1.1.0 | MIT | Request timeout library for Excimer with plain PHP fallback | Tim Starling
wikimedia/running-stat | 1.2.1 | GPL-2.0+ | PHP implementations of online statistical algorithms | Ori Livneh
wikimedia/scoped-callback | 3.0.0 | GPL-2.0-or-later | Class for asserting that a callback happens when a dummy object leaves scope | Aaron Schulz
wikimedia/services | 2.0.1 | GPL-2.0-or-later | Generic service to manage named services using lazy instantiation based on instantiator callback functions | Daniel Kinzler
wikimedia/shellbox | 1.0.4 | MIT | Library and server for containerized shell execution | Tim Starling、Kunal Mehta和Max Semenik
wikimedia/testing-access-wrapper | 2.0.0 | GPL-2.0-or-later | A simple helper class to access non-public elements of a class when testing. | Adam Roses Wight、Brad Jorsch和Gergő Tisza
wikimedia/timestamp | 3.0.0 | GPL-2.0-or-later | Creation, parsing, and conversion of timestamps | Tyler Romeo
wikimedia/utfnormal | 3.0.2 | GPL-2.0-or-later | Contains Unicode normalization routines, including both pure PHP implementations and automatic use of the 'intl' PHP extension when present | Brion Vibber
wikimedia/wait-condition-loop | 2.0.1 | GPL-2.0-or-later | Wait loop that reaches a condition or times out | Aaron Schulz
wikimedia/wikipeg | 2.0.5 | MIT | Parser generator for JavaScript and PHP |
wikimedia/wrappedstring | 3.2.0 | MIT | Automatically compact sequentially-outputted strings that share a common prefix / suffix pair. | Timo Tijhof
wikimedia/xmp-reader | 0.8.1 | GPL-2.0-or-later | Reader for XMP data containing properties relevant to images | Brian Wolff
wikimedia/zest-css | 1.1.5 | MIT | Fast, lightweight, extensible CSS selector engine for PHP | Christopher Jeffrey和C. Scott Ananian
zordius/lightncandy | 1.2.5 | MIT | An extremely fast PHP implementation of handlebars ( http://handlebarsjs.com/ ) and mustache ( http://mustache.github.io/ ). | Zordius Chen

## 解析器扩展标签

<categorytree>、<gallery>、<imagemap>、<indicator>、<inputbox>、<langconvert>、<nowiki>、<poem>、<pre>、<ref>、<references>、<source>、<syntaxhighlight>、<templatedata>和<templatestyles>

## 解析器函数钩

anchorencode、basepagename、basepagenamee、bidi、canonicalurl、canonicalurle、cascadingsources、categorytree、defaultsort、displaytitle、expr、filepath、formatdate、formatnum、fullpagename、fullpagenamee、fullurl、fullurle、gender、grammar、if、ifeq、iferror、ifexist、ifexpr、int、invoke、language、lc、lcfirst、localurl、localurle、namespace、namespacee、namespacenumber、ns、nse、numberingroup、numberofactiveusers、numberofadmins、numberofarticles、numberofedits、numberoffiles、numberofpages、numberofusers、padleft、padright、pageid、pagename、pagenamee、pagesincategory、pagesize、plural、protectionexpiry、protectionlevel、rel2abs、revisionday、revisionday2、revisionid、revisionmonth、revisionmonth1、revisiontimestamp、revisionuser、revisionyear、rootpagename、rootpagenamee、special、speciale、subjectpagename、subjectpagenamee、subjectspace、subjectspacee、subpagename、subpagenamee、switch、tag、talkpagename、talkpagenamee、talkspace、talkspacee、time、timel、titleparts、uc、ucfirst和urlencode visited from 0.0.0.0
取自“https://wiki.othing.xyz/wiki/Special:版本”